@@ -7,7 +7,7 @@ use warnings;
 use Carp         'confess';
 use Scalar::Util 'blessed', 'weaken', 'looks_like_number';
 
-our $VERSION   = '0.75';
+our $VERSION   = '0.76';
 $VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
@@ -89,6 +89,8 @@ sub generate_constructor_method {
 sub generate_constructor_method_inline {
     my $self = shift;
 
+    my $close_over = {};
+
     my $source = 'sub {';
     $source .= "\n" . 'my $class = shift;';
 
@@ -99,7 +101,7 @@ sub generate_constructor_method_inline {
 
     $source .= "\n" . 'my $instance = ' . $self->meta_instance->inline_create_instance('$class');
     $source .= ";\n" . (join ";\n" => map {
-        $self->_generate_slot_initializer($_)
+        $self->_generate_slot_initializer($_, $close_over)
     } 0 .. (@{$self->attributes} - 1));
     $source .= ";\n" . 'return $instance';
     $source .= ";\n" . '}';
@@ -110,9 +112,11 @@ sub generate_constructor_method_inline {
         # NOTE:
         # create the nessecary lexicals
         # to be picked up in the eval
-        my $attrs = $self->attributes;
 
-        $code = eval $source;
+        $code = $self->_eval_closure(
+            $close_over,
+            $source
+        );
         confess "Could not eval the constructor :\n\n$source\n\nbecause :\n\n$@" if $@;
     }
     return $code;
@@ -121,6 +125,7 @@ sub generate_constructor_method_inline {
 sub _generate_slot_initializer {
     my $self  = shift;
     my $index = shift;
+    my $close = shift;
 
     my $attr = $self->attributes->[$index];
 
@@ -133,7 +138,9 @@ sub _generate_slot_initializer {
         # in which case we can just deal with them
         # in the code we eval.
         if ($attr->is_default_a_coderef) {
-            $default = '$attrs->[' . $index . ']->default($instance)';
+            my $idx = @{$close->{'@defaults'}||=[]};
+            push(@{$close->{'@defaults'}}, $attr->default);
+            $default = '$defaults[' . $idx . ']->($instance)';
         }
         else {
             $default = $attr->default;
